@@ -21,13 +21,15 @@
 #' conjunction with \code{allow.array}
 #' @export 
 #' @author John Muschelli \email{muschellij2@@gmail.com} 
+#' 
+#' @examples 
+#' x = nifti()
+#' check_nifti(x)
 setGeneric("check_nifti", 
            function(x, reorient=FALSE, 
                     allow.array=FALSE,
                     fast = FALSE,
-                    need_header = TRUE) {
-             standardGeneric("check_nifti")
-           })
+                    need_header = TRUE) standardGeneric("check_nifti"))
 
 #' @rdname check_nifti-methods
 #' @aliases check_nifti,nifti-method
