@@ -4,9 +4,11 @@
 #' @param x Object of class \code{nifti}
 #' @param zlim A user-specified \code{zlim}.  If \code{NULL}, will calculate how 
 #' \code{\link{ortho2}} would calculate \code{zlim}
+#' @param computed_range If the range of the data was already computed,
+#' this can be passed in and will be used if relevant.
 #' @return If \code{zlim = NULL}, then vector of length 2, otherwise returns \code{zlim}
 #' @export
-zlimmer = function(x, zlim = NULL){
+zlimmer = function(x, zlim = NULL, computed_range = NULL){
   if (is.null(x)) {
     return(NULL)
   }
@@ -22,7 +24,13 @@ zlimmer = function(x, zlim = NULL){
       zlim = c(0, 0)
     }
     if (any(!is.finite(zlim)) || diff(zlim) == 0) {
-      zlim <- range(x, na.rm = TRUE)
+      if (!is.null(computed_range)) {
+        stopifnot(length(computed_range) == 2)
+        stopifnot(!any(is.na(computed_range)))
+        zlim = computed_range
+      } else {
+        zlim <- range(x, na.rm = TRUE)
+      }
     }
   }
   return(zlim)
